@@ -1361,16 +1361,18 @@ class VariableOsLocationFormat(LocationHelper, Variable):
                     return "swap"
                 elif mount.startswith('/boot/efi'):
                     return "vfat"
-                if mount == "/" and root_format and root_format in allAvailFS:
-                    return root_format
-                if dev in diskFormat and diskFormat[dev] in allAvailFS:
-                    if mount.count('/') == 1 or mount == "/var/calculate":
-                        if FileSystemManager.checkFSForTypeMount(
-                                diskFormat[dev],
-                                osInstallRootType, mount):
+                if mount == "/":
+                    if root_format and root_format in allAvailFS:
+                        return root_format
+                else:
+                    if dev in diskFormat and diskFormat[dev] in allAvailFS:
+                        if mount.count('/') == 1 or mount == "/var/calculate":
+                            if FileSystemManager.checkFSForTypeMount(
+                                    diskFormat[dev],
+                                    osInstallRootType, mount):
+                                return diskFormat[dev]
+                        else:
                             return diskFormat[dev]
-                    else:
-                        return diskFormat[dev]
                 if default_format:
                     return default_format
                 return FileSystemManager.defaultFS.get(
